summaryrefslogtreecommitdiffstats
path: root/lib/kofficecore/KoPictureCollection.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kofficecore/KoPictureCollection.h')
-rw-r--r--lib/kofficecore/KoPictureCollection.h36
1 files changed, 18 insertions, 18 deletions
diff --git a/lib/kofficecore/KoPictureCollection.h b/lib/kofficecore/KoPictureCollection.h
index 22277bdd..8071d564 100644
--- a/lib/kofficecore/KoPictureCollection.h
+++ b/lib/kofficecore/KoPictureCollection.h
@@ -22,9 +22,9 @@
#ifndef koPictureCollection_h
#define koPictureCollection_h
-#include <qmap.h>
-#include <qdom.h>
-#include <qvaluelist.h>
+#include <tqmap.h>
+#include <tqdom.h>
+#include <tqvaluelist.h>
#include "KoPicture.h"
@@ -37,7 +37,7 @@ class KoXmlWriter;
* A collection of pictures (a key and the picture itself).
*
*/
-class KOFFICECORE_EXPORT KoPictureCollection : public QMap<KoPictureKey, KoPicture>
+class KOFFICECORE_EXPORT KoPictureCollection : public TQMap<KoPictureKey, KoPicture>
{
public:
enum Type {
@@ -71,10 +71,10 @@ public:
* If this file is really remote, it is always downloaded.
* If the file is local, it acts as @ref #loadPicture.
* @param url the URL to download from
- * @param window the parent window for the download. You can pass NULL (0)
+ * @param window the tqparent window for the download. You can pass NULL (0)
* if you absolutely cannot find anything to use.
*/
- KoPicture downloadPicture(const KURL& url, QWidget *window);
+ KoPicture downloadPicture(const KURL& url, TQWidget *window);
/**
* @brief Load a clipart from a file (and insert into the collection).
@@ -83,7 +83,7 @@ public:
* for this clipart. If this key maps to an existing clipart in the
* collection, then this picture is returned, otherwise the file is loaded.
*/
- KoPicture loadPicture( const QString &fileName );
+ KoPicture loadPicture( const TQString &fileName );
/**
* Save the used picturess from the collection into the store
@@ -96,7 +96,7 @@ public:
*
* @todo Reduce lameness of dox for pictureType.
*/
- bool saveToStore(const Type pictureType, KoStore * store, const QValueList<KoPictureKey>& keys );
+ bool saveToStore(const Type pictureType, KoStore * store, const TQValueList<KoPictureKey>& keys );
/**
* Generate the &lt;PICTURES&gt;, &lt;PIXMAPS> or &lt;CLIPARTS> tag, that saves the key and the related
@@ -106,26 +106,26 @@ public:
* @param doc the DOM document in which the tags are to be generated
* @param keys the list of keys
*/
- QDomElement saveXML(const Type pictureType, QDomDocument &doc,
- QValueList<KoPictureKey> keys );
+ TQDomElement saveXML(const Type pictureType, TQDomDocument &doc,
+ TQValueList<KoPictureKey> keys );
- bool saveOasisToStore( KoStore *store, QValueList<KoPictureKey> keys, KoXmlWriter* manifestWriter );
+ bool saveOasisToStore( KoStore *store, TQValueList<KoPictureKey> keys, KoXmlWriter* manifestWriter );
- typedef QMap<KoPictureKey, QString> StoreMap;
+ typedef TQMap<KoPictureKey, TQString> StoreMap;
/**
* Read the &lt;PICTURES&gt;, &lt;PIXMAPS> or &lt;CLIPARTS> tag, and save the result (key<->store-filename associations)
* into the QMap. You may want to 'new' a QMap in loadXML, and to use and then delete
* it in completeLoading (to save memory).
*
* @param pixmapsElem the &lt;PICTURES&gt;, &lt;PIXMAPS> or &lt;CLIPARTS> element
*/
- StoreMap readXML( QDomElement &pixmapsElem );
+ StoreMap readXML( TQDomElement &pixmapsElem );
/**
* Helper method for @ref #readFromStore
*/
- void readXML( QDomElement& pixmapsElem, QMap <KoPictureKey, QString>& map );
+ void readXML( TQDomElement& pixmapsElem, TQMap <KoPictureKey, TQString>& map );
/**
* Read all pictures from the store, into this collection
@@ -144,13 +144,13 @@ public:
*
* Formerly, an invalid date/time meant to read the file from disk. This is not the case anymore.
*/
- KoPicture findOrLoad(const QString& fileName, const QDateTime& dateTime);
+ KoPicture findOrLoad(const TQString& fileName, const TQDateTime& dateTime);
/**
* Return filename as url for picture
*
*/
- QString getOasisFileName(const KoPicture& picture) const;
+ TQString getOasisFileName(const KoPicture& picture) const;
/**
* Call it before to save Oasis file
@@ -162,7 +162,7 @@ private:
/**
* @internal
*/
- QString getFileName(const Type pictureType, KoPicture& picture, int& counter);
+ TQString getFileName(const Type pictureType, KoPicture& picture, int& counter);
class Private;
Private* d;
@@ -106,26 +106,26 @@ public:
/**
* Read the &lt;PICTURES&gt;, &lt;PIXMAPS> or &lt;CLIPARTS> tag, and save the result (key<->store-filename associations)
- * into the QMap. You may want to 'new' a QMap in loadXML, and to use and then delete
+ * into the TQMap. You may want to 'new' a TQMap in loadXML, and to use and then delete
* it in completeLoading (to save memory).
*